@@ -1,6 +1,6 @@
-#![cfg(target_os = "linux")]
+#![cfg(any(target_os = "linux", target_os = "android"))]
 #![doc = include_str!("../README.md")]
-#![doc(html_root_url = "https://docs.rs/selinux/0.5.1")]
+#![doc(html_root_url = "https://docs.rs/selinux/0.5.2")]
 #![allow(clippy::upper_case_acronyms)]
 #![warn(
     unsafe_op_in_unsafe_fn,
